# url-instax

[![Release](https://img.shields.io/github/v/release/wh1isper/url-instax)](https://img.shields.io/github/v/release/wh1isper/url-instax)
[![Build status](https://img.shields.io/github/actions/workflow/status/wh1isper/url-instax/main.yml?branch=main)](https://github.com/wh1isper/url-instax/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/wh1isper/url-instax)](https://img.shields.io/github/commit-activity/m/wh1isper/url-instax)
[![License](https://img.shields.io/github/license/wh1isper/url-instax)](https://img.shields.io/github/license/wh1isper/url-instax)

Screenshot for web page.
